@@ -215,6 +215,8 @@ class SpatialGraph():
                 y_ = 0
                 _y = 1
 
+            print(axd)
+
             con = ConnectionPatch(xyA=(dem_plots[i], y_),
                                   coordsA=axd['bar'].transData,
                                   xyB=(np.mean(axd[plot_name].get_xlim()),
@@ -443,6 +445,7 @@ class SpatialGraph():
                 f_umap.data[0].selectedpoints = plot.selectedpoints
 
             else:
+                print(f_scatter.data)
                 f_scatter.data[-1].selectedpoints = plot.selectedpoints
 
             subset = self.sdata[np.array(points.point_inds)]
