@@ -1,5 +1,5 @@
 
-from __future__ import annotations
+# from __future__ import annotations
 from tokenize import group
 
 from matplotlib import cm
@@ -995,6 +995,8 @@ class SpatialData(pd.DataFrame):
 
         out = widgets.Output(layout={'border': '1px solid black'})
 
+        print('kewl')
+
         def update_bars(plot, points, selector):
 
             subset = self[np.array(points.point_inds)]
